# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.1.0

([Full Changelog](https://github.com/jupyterlite/jupyterlab-codestral/compare/9c8d350b8876ad3a9ffe8dbe723ca093bb680681...b77e9e9a563cda3b9d37972248e738746f7370a8))

### Maintenance and upkeep improvements

- Reset version [#4](https://github.com/jupyterlite/jupyterlab-codestral/pull/4) ([@jtpio](https://github.com/jtpio))

### Documentation improvements

- Add disclaimer [#3](https://github.com/jupyterlite/jupyterlab-codestral/pull/3) ([@jtpio](https://github.com/jtpio))
- Update links to the repo [#2](https://github.com/jupyterlite/jupyterlab-codestral/pull/2) ([@jtpio](https://github.com/jtpio))
- Add files for a JupyterLite demo [#1](https://github.com/jupyterlite/jupyterlab-codestral/pull/1) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/jupyterlab-codestral/graphs/contributors?from=2024-06-10&to=2024-06-24&type=c))

[@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fjupyterlab-codestral+involves%3Ajtpio+updated%3A2024-06-10..2024-06-24&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->
